@@ -80,6 +80,9 @@ _FUNC_2_DATATYPE = {
   #"SIMPLEREPLACE" :  # ok
   "NEWINSTANCEIRI" : None, # ok
 
+  "HTTP://WWW.W3.ORG/2001/XMLSCHEMA#INTEGER" : _universal_datatype_2_abbrev[int], # ok
+  "HTTP://WWW.W3.ORG/2001/XMLSCHEMA#DOUBLE" : _universal_datatype_2_abbrev[float], # ok
+  
   "COUNT" : _universal_datatype_2_abbrev[int], # ok
   "MIN" : 0, # ok
   "MAX" : 0, # ok
@@ -217,6 +220,10 @@ def register_python_function(world):
   create_function("bnode",          -1, func._bnode)
   create_function("newinstanceiri",  1, func._newinstanceiri)
   
+  # Unindexed table for deprioritizing subqueries
+  world.graph.execute("""CREATE TEMP TABLE one (i INTEGER)""") # CREATE TEMP TABLE one (i INTEGER); INSERT INTO one VALUES (1);
+  world.graph.execute("""INSERT INTO one VALUES (1)""")
+  
   
 class FuncSupport(object):
   def parse_expression(self, expression):
@@ -247,6 +254,12 @@ class FuncSupport(object):
             if   e_type == "objs":  return "(SELECT iri FROM resources WHERE storid=%s)" % eo
             elif e_type == "datas": return "''||%s" % eo
             else:                   return "IIF(%s IS NULL, (SELECT iri FROM resources WHERE storid=%s), ''||%s)" % (ed, eo, eo)
+          elif func == "HTTP://WWW.W3.ORG/2001/XMLSCHEMA#DOUBLE":
+            eo = self.parse_expression(expression[2])
+            return "CAST(%s AS DOUBLE)" % eo
+          elif func == "HTTP://WWW.W3.ORG/2001/XMLSCHEMA#INTEGER":
+            eo = self.parse_expression(expression[2])
+            return "CAST(%s AS INTEGER)" % eo
           elif (func == "IRI") or (func == "URI"):
             eo         = self.parse_expression     (expression[2])
             e_type, ed = self.infer_expression_type(expression[2])
@@ -329,7 +342,10 @@ class FuncSupport(object):
           
         return "".join(self.parse_expression(i) for i in expression) 
     elif expression is None: pass
-    elif expression.name  == "VAR":    return self.parse_var(expression).bindings[0]
+    elif expression.name  == "VAR":
+      #print(expression, self.vars, self.parse_var(expression))
+      
+      return self.parse_var(expression).get_binding(self)
     elif expression.name  == "PARAM":  return "?%s" % expression.number
     elif expression.value == "(":      return "("
     elif expression.value == ")":      return ")"
@@ -413,7 +429,7 @@ class FuncSupport(object):
     elif  expression.name == "VAR":
       var = self.parse_var(expression)
       if var.type == "objs": return "objs", "NULL"
-      return var.type, "%sd" % var.bindings[0][:-1]
+      return var.type, "%sd" % var.get_binding(self)[:-1]
     elif  expression.name == "PARAM":
       return "quads", "%sTypeOfParam?%s " % (self.translator.escape_mark, expression.number)
     return None, None
